export declare enum ESearchQuerySortColumns {
    Name = "name",
    Price = "price",
    PriceMod = "price_mod",
    Default = "default"
}
export declare enum ESearchQuerySortOrders {
    Asc = "asc",
    Desc = "desc"
}
export interface ISearchQueryParams {
    sort: ESearchQuerySortColumns;
    order: ESearchQuerySortOrders;
    q?: string;
    page?: number;
    count?: number;
    type_id?: number;
    subtype_id?: number;
    relation_type?: string;
    trade_companies?: {
        company_id: number;
        trade_type_id: number;
    }[];
}
export interface IBaseEntity {
    id: number;
    name: string;
}
export interface ISearchInfoCompany extends IBaseEntity {
    alias: string;
}
export type ISearchInfoRelationTypes = string[];
export interface ISearchInfoTradeType extends IBaseEntity {
}
export interface ISearchInfoTypes extends IBaseEntity {
    subtypes: ISearchInfoTypes[];
}
export interface ISearchInfoResponse {
    companies: ISearchInfoCompany[];
    relation_types: ISearchInfoRelationTypes[];
    trade_types: ISearchInfoTradeType[];
    types: ISearchInfoTypes[];
}
export interface ISearchDocumentNameAlias {
    company_id: number;
    instrument_name: number;
    trade_type_id: number;
}
export interface ISearchQueryDocument extends IBaseEntity {
    description: string;
    account_type: string;
    relation_type: string;
    type_id: number;
    subtype_id: number;
    price_change: number;
    lld: string;
    lll: string;
    lsd: string;
    lsl: string;
    aliases: string[];
    name_aliases: ISearchDocumentNameAlias[];
    company_ids: number[];
    exchange: string;
    country: string;
    consensus: string;
    sector: string;
    currency: string;
    market_capitalization: unknown;
    sentiment_rank: unknown;
    sector_size: unknown;
}
export interface ISearchQueryHit {
    document: ISearchQueryDocument;
    highlight: unknown;
    highlights: unknown;
}
export interface ISearchQueryResponse {
    found: number;
    page: number;
    hits: ISearchQueryHit[];
}
