import { IRecentlyViewedInstrument } from './utils';
import { ISearchQueryParams, SearchAPI, ISearchQueryDocument } from './api';
export declare enum ESearchFiltersPresets {
    invest = 1,
    trading = 2,
    both = 3
}
export declare enum ESearchQueryTypes {
    Currencies = 1,
    Commodities = 2,
    Indices = 3,
    Stocks = 4,
    Bonds = 147,
    Cryptocurrencies = 199,
    ClassicStocks = 206,
    ETF = 4317,
    ClassicETF = 4318
}
export interface ISearchModalFiltersLabels {
    currencies: string;
    commodities: string;
    indices: string;
    stocks: string;
    bonds: string;
    cryptocurrencies: string;
    etf: string;
    classic_stocks: string;
    classic_etf: string;
}
export interface ISearchModalRequiredLabels {
    title: string;
    inputPlaceholder: string;
    recentlyViewedLabel: string;
    recentlyViewedEmptyStateLabel: string;
    emptyStateLabel: string;
    loadingLabel: string;
    initialStateLabel: string;
    errorStateLabel: string;
    instrumentHeaderLabel: string;
    instrumentPriceChangeLabel: string;
}
export interface ISearchModalAdditionalLabels {
    viewAllButtonLabel?: string;
    filterLabels?: ISearchModalFiltersLabels;
}
export type ISearchModalLabels = ISearchModalRequiredLabels & ISearchModalAdditionalLabels;
export interface ISearchModalProps {
    modelValue: boolean;
    labels: ISearchModalLabels;
    prefix: string;
    enableRecentlyViewed?: boolean;
    viewAllButton?: boolean;
    entityId?: number | string;
    searchQuery?: string;
    recentlyViewedInstrumentsMaxCount?: number;
    searchInstrumentsMaxCount?: number;
    includeInfoRequest?: boolean;
    dialogZIndex?: number;
    dialogWidth?: number;
    infoCallback?: SearchAPI['getSearchInfo'];
    queryCallback?: SearchAPI['searchInstruments'];
    requestQueryTradeCompanies?: ISearchQueryParams['trade_companies'];
    requestQueryTypeId?: ESearchQueryTypes;
    requestQuerySubTypeId?: number;
    requestQueryRelationType?: string;
    searchFiltersPreset?: ESearchFiltersPresets;
    isCryptoAllowed?: boolean;
}
export interface ISearchModalEmits {
    (e: 'close-modal'): void;
    (e: 'update:model-value', value: boolean): void;
    (e: 'click-on-instrument', name: string, instrument: ISearchQueryDocument): void;
    (e: 'click-on-view-all', query: string): void;
}
export interface ISearchResultSlot {
    foundInstruments: ISearchQueryDocument[];
    isEmpty: boolean;
}
export interface IRecentlyViewedSlot {
    recentlyViewedInstruments: IRecentlyViewedInstrument[];
    isEmpty: boolean;
}
export type TQueryExtendableFilters = Partial<Pick<ISearchQueryParams, 'trade_companies' | 'type_id' | 'relation_type' | 'subtype_id'>>;
export interface IInstrumentFilter {
    id: number;
    label: string;
    filter: TQueryExtendableFilters;
}
